@@ -49,7 +49,7 @@ namespace newsbeuter {
 			void record_google_replay(const std::string& guid, bool read);
 			void catchup_all();
 			inline void catchup_all(std::tr1::shared_ptr<rss_feed> feed) { rsscache->catchup_all(feed); }
-			inline bool get_refresh_on_start() { return refresh_on_start; }
+			inline bool get_refresh_on_start() const { return refresh_on_start; }
 			bool is_valid_podcast_type(const std::string& mimetype);
 			void enqueue_url(const std::string& url, std::tr1::shared_ptr<rss_feed> feed);
 			void notify(const std::string& msg);
@@ -84,10 +84,12 @@ namespace newsbeuter {
 			void sort_feeds();
 
 			void update_flags(std::tr1::shared_ptr<rss_item> item);
+
+			unsigned int get_feed_count_per_tag(const std::string& tag);
 		private:
 			void usage(char * argv0);
-			bool setup_dirs_xdg(const char *env_home);
-			void setup_dirs();
+			bool setup_dirs_xdg(const char *env_home, bool silent);
+			void setup_dirs(bool silent);
 			void version_information(const char * argv0, unsigned int level);
 			void import_opml(const char * filename);
 			void export_opml();
