@@ -81,7 +81,7 @@ class utils {
 		static void set_common_curl_options(CURL * handle, configcontainer * cfg);
 
 		static curl_proxytype get_proxy_type(const std::string& type);
-		static int get_proxy_auth_method(const std::string& type);
+		static int get_auth_method(const std::string& type);
 
 		static bool is_special_url(const std::string& url);
 
@@ -92,6 +92,7 @@ class utils {
 
 		static std::string escape_url(const std::string& url);
 		static std::string unescape_url(const std::string& url);
+		static void initialize_ssl_implementation(void);
 
 	private:
 		static void append_escapes(std::string& str, char c);
