@@ -1,4 +1,4 @@
-/* rsspp - Copyright (C) 2008-2011 Andreas Krennmair <ak@newsbeuter.org>
+/* rsspp - Copyright (C) 2008-2012 Andreas Krennmair <ak@newsbeuter.org>
  * Licensed under the MIT/X Consortium License. See file LICENSE
  * for more information.
  */
@@ -15,7 +15,7 @@
 
 namespace rsspp {
 
-enum version { UNKNOWN = 0, RSS_0_91, RSS_0_92, RSS_1_0, RSS_2_0, ATOM_0_3, ATOM_1_0, RSS_0_94, ATOM_0_3_NONS };
+enum version { UNKNOWN = 0, RSS_0_91, RSS_0_92, RSS_1_0, RSS_2_0, ATOM_0_3, ATOM_1_0, RSS_0_94, ATOM_0_3_NONS, TTRSS_JSON };
 
 struct item {
 	std::string title;
@@ -41,6 +41,9 @@ struct item {
 	// Atom-specific:
 	std::string base;
 	std::vector<std::string> labels;
+
+	// only required for ttrss support:
+	time_t pubDate_ts;
 };
 
 struct feed {
