@@ -118,7 +118,8 @@ static int rssitem_callback(void * myfeed, int argc, char ** argv, char ** /* az
 	item->set_flags(argv[11] ? argv[11] : "");
 	item->set_base(argv[12] ? argv[12] : "");
 
-	(*feed)->items().push_back(item);
+	//(*feed)->items().push_back(item);
+	(*feed)->add_item(item);
 	return 0;
 }
 
@@ -163,12 +164,6 @@ static int search_item_callback(void * myfeed, int argc, char ** argv, char ** /
 
 
 cache::cache(const std::string& cachefile, configcontainer * c) : db(0),cfg(c) {
-	bool file_exists = false;
-	std::fstream f;
-	f.open(cachefile.c_str(), std::fstream::in | std::fstream::out);
-	if (f.is_open()) {
-		file_exists = true;
-	}
 	int error = sqlite3_open(cachefile.c_str(),&db);
 	if (error != SQLITE_OK) {
 		LOG(LOG_ERROR,"couldn't sqlite3_open(%s): error = %d", cachefile.c_str(), error);
@@ -353,6 +348,11 @@ void cache::externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_
 
 	cb_handler count_cbh;
 	int rc = sqlite3_exec(db,prepare_query("SELECT count(*) FROM rss_feed WHERE rssurl = '%q';", feed->rssurl().c_str()).c_str(),count_callback,&count_cbh,NULL);
+	if (rc != SQLITE_OK) {
+		LOG(LOG_CRITICAL,"query failed: error = %d", rc);
+		throw dbexception(db);
+	}
+
 	int count = count_cbh.count();
 	LOG(LOG_DEBUG, "cache::externalize_rss_feed: rss_feeds with rssurl = '%s': found %d",feed->rssurl().c_str(), count);
 	if (count > 0) {
@@ -369,14 +369,14 @@ void cache::externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_
 	
 	unsigned int max_items = cfg->get_configvalue_as_int("max-items");
 
-	LOG(LOG_INFO, "cache::externalize_feed: max_items = %u feed.items().size() = %u", max_items, feed->items().size());
+	LOG(LOG_INFO, "cache::externalize_feed: max_items = %u feed.items().size() = %u", max_items, feed->total_item_count());
 	
 	if (max_items > 0 && feed->items().size() > max_items) {
 		std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();
 		for (unsigned int i=0;i<max_items;++i)
 			++it;	
 		if (it != feed->items().end())
-			feed->items().erase(it, feed->items().end()); // delete entries that are too much
+			feed->erase_items(it, feed->items().end()); // delete entries that are too much
 	}
 
 	unsigned int days = cfg->get_configvalue_as_int("keep-articles-days");
@@ -422,7 +422,7 @@ void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores
 		throw dbexception(db);
 	}
 
-	feed->items().clear();
+	feed->clear_items();
 
 	/* ...and then the associated items */
 	query = prepare_query("SELECT guid,title,author,url,pubDate,length(content),unread,feedurl,enclosure_url,enclosure_type,enqueued,flags,base FROM rss_item WHERE feedurl = '%q' AND deleted = 0 ORDER BY pubDate DESC, id DESC;",feed->rssurl().c_str());
@@ -436,13 +436,13 @@ void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores
 	unsigned int i=0;
 	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin(); it != feed->items().end(); ++it,++i) {
 		if (ign && ign->matches(it->get())) {
-			feed->items().erase(it);
+			feed->erase_item(it);
 			// since we modified the vector, we need to reset the iterator
 			// to the beginning of the vector, and then fast-forward to
 			// the next element.
 			it = feed->items().begin();
 			for (int j=0;j<int(i)-1;j++) {
-				it++;
+				++it;
 			}
 			continue;
 		}
@@ -465,9 +465,12 @@ void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores
 				flagged_items.push_back(feed->items()[i]);
 			}
 		}	
-		feed->items().erase(it, feed->items().end()); // delete old entries
+		feed->erase_items(it, feed->items().end()); // delete old entries
 		if (flagged_items.size() > 0) {
-			feed->items().insert(feed->items().end(), flagged_items.begin(), flagged_items.end()); // if some flagged articles were saved, append them
+			// if some flagged articles were saved, append them
+			for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator jt=flagged_items.begin();jt!=flagged_items.end();++jt) {
+				feed->add_item(*jt);
+			}
 		}
 	}
 	feed->sort_unlocked(cfg->get_configvalue("article-sort-order"));
@@ -552,6 +555,8 @@ void cache::cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
 		cleanup_rss_items_statement.append(list);
 		cleanup_rss_items_statement.append(1,';');
 
+		std::string cleanup_read_items_statement("DELETE FROM rss_item WHERE unread = 0");
+
 		// std::cerr << "statements: " << cleanup_rss_feeds_statement << " " << cleanup_rss_items_statement << std::endl;
 
 		LOG(LOG_DEBUG,"running query: %s", cleanup_rss_feeds_statement.c_str());
@@ -568,6 +573,15 @@ void cache::cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
 			throw dbexception(db);
 		}
 
+		if (cfg->get_configvalue_as_bool("delete-read-articles-on-quit")) {
+			LOG(LOG_DEBUG,"running query: %s", cleanup_read_items_statement.c_str());
+			rc = sqlite3_exec(db,cleanup_read_items_statement.c_str(),NULL,NULL,NULL);
+			if (rc != SQLITE_OK) {
+				LOG(LOG_CRITICAL,"query \"%s\" failed: error = %d", cleanup_read_items_statement.c_str(), rc);
+				throw dbexception(db);
+			}
+		}
+
 		// WARNING: THE MISSING UNLOCK OPERATION IS MISSING FOR A PURPOSE!
 		// It's missing so that no database operation can occur after the cache cleanup!
 		// mtx->unlock();
@@ -810,10 +824,10 @@ unsigned int cache::get_unread_count() {
 	return count;
 }
 
-void cache::mark_items_read_by_guid(const std::vector<std::string> guids) {
+void cache::mark_items_read_by_guid(const std::vector<std::string>& guids) {
 	scope_measure m1("cache::mark_items_read_by_guid");
 	std::string guidset("(");
-	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();it++) {
+	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();++it) {
 		guidset.append(prepare_query("'%q', ", it->c_str()));
 	}
 	guidset.append("'')");
@@ -855,7 +869,6 @@ std::vector<std::string> cache::get_read_item_guids() {
 
 void cache::clean_old_articles() {
 	scope_mutex lock(&mtx);
-	int rc;
 
 	unsigned int days = cfg->get_configvalue_as_int("keep-articles-days");
 	if (days > 0) {
@@ -863,7 +876,7 @@ void cache::clean_old_articles() {
 
 		std::string query(utils::strprintf("DELETE FROM rss_item WHERE pubDate < %d", old_date));
 		LOG(LOG_DEBUG, "cache::clean_old_articles: about to delete articles with a pubDate older than %d", old_date);
-		rc = sqlite3_exec(db, query.c_str(), NULL, NULL, NULL);
+		int rc = sqlite3_exec(db, query.c_str(), NULL, NULL, NULL);
 		LOG(LOG_DEBUG, "cache::clean_old_artgicles: old article delete result: rc = %d", rc);
 	} else {
 		LOG(LOG_DEBUG, "cache::clean_old_articles, days == 0, not cleaning up anything");
@@ -873,7 +886,7 @@ void cache::clean_old_articles() {
 void cache::fetch_descriptions(rss_feed * feed) {
 	std::vector<std::tr1::shared_ptr<rss_item> >& items = feed->items();
 	std::vector<std::string> guids;
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items.begin();it!=items.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items.begin();it!=items.end();++it) {
 		guids.push_back(prepare_query("'%q'", (*it)->guid().c_str()));
 	}
 	std::string in_clause = utils::join(guids, ", ");
@@ -901,7 +914,7 @@ void cache::record_google_replay(const std::string& guid, unsigned int state) {
 void cache::delete_google_replay_by_guid(const std::vector<std::string>& guids) {
 	std::vector<std::string> escaped_guids;
 
-	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();it++) {
+	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();++it) {
 		escaped_guids.push_back(prepare_query("'%q'", it->c_str()));
 	}
 
