@@ -66,10 +66,10 @@ void colormanager::handle_action(const std::string& action, const std::vector<st
 }
 
 void colormanager::dump_config(std::vector<std::string>& config_output) {
-	for (std::map<std::string, std::string>::iterator it=fg_colors.begin();it!=fg_colors.end();it++) {
+	for (std::map<std::string, std::string>::iterator it=fg_colors.begin();it!=fg_colors.end();++it) {
 		std::string configline = utils::strprintf("color %s %s %s", it->first.c_str(), it->second.c_str(), bg_colors[it->first].c_str());
 		std::vector<std::string> attribs = attributes[it->first];
-		for (std::vector<std::string>::iterator jt=attribs.begin();jt!=attribs.end();jt++) {
+		for (std::vector<std::string>::iterator jt=attribs.begin();jt!=attribs.end();++jt) {
 			configline.append(" ");
 			configline.append(*jt);
 		}
