@@ -15,6 +15,7 @@
 #include <rss_parser.h>
 #include <remote_api.h>
 #include <google_api.h>
+#include <ttrss_api.h>
 #include <xlicense.h>
 
 #include <cstdlib>
@@ -38,7 +39,7 @@
 #include <sys/stat.h>
 #include <pwd.h>
 
-#include <ncursesw/ncurses.h>
+#include <ncurses.h>
 
 #include <libxml/xmlversion.h>
 #include <libxml/parser.h>
@@ -86,7 +87,7 @@ controller::controller() : v(0), urlcfg(0), rsscache(0), url_file("urls"), cache
  *
  * returns false, if that fails
  */
-bool controller::setup_dirs_xdg(const char *env_home) {
+bool controller::setup_dirs_xdg(const char *env_home, bool silent) {
 	const char *env_xdg_config;
 	const char *env_xdg_data;
 	std::string xdg_config_dir;
@@ -120,12 +121,16 @@ bool controller::setup_dirs_xdg(const char *env_home) {
 
 	if (access(xdg_config_dir.c_str(), R_OK | X_OK) != 0)
 	{
-		std::cout << utils::strprintf(_("XDG: configuration directory '%s' not accessible, using '%s' instead."), xdg_config_dir.c_str(), config_dir.c_str()) << std::endl;
+		if (!silent) {
+			std::cerr << utils::strprintf(_("XDG: configuration directory '%s' not accessible, using '%s' instead."), xdg_config_dir.c_str(), config_dir.c_str()) << std::endl;
+		}
 		return false;
 	}
 	if (access(xdg_data_dir.c_str(), R_OK | X_OK | W_OK) != 0)
 	{
-		std::cout << utils::strprintf(_("XDG: data directory '%s' not accessible, using '%s' instead."), xdg_data_dir.c_str(), config_dir.c_str()) << std::endl;
+		if (!silent) {
+			std::cerr << utils::strprintf(_("XDG: data directory '%s' not accessible, using '%s' instead."), xdg_data_dir.c_str(), config_dir.c_str()) << std::endl;
+		}
 		return false;
 	}
 
@@ -145,7 +150,7 @@ bool controller::setup_dirs_xdg(const char *env_home) {
 	return true;
 }
 
-void controller::setup_dirs() {
+void controller::setup_dirs(bool silent) {
 	const char * env_home;
 	if (!(env_home = ::getenv("HOME"))) {
 		struct passwd * spw = ::getpwuid(::getuid());
@@ -162,7 +167,7 @@ void controller::setup_dirs() {
 	config_dir.append(NEWSBEUTER_PATH_SEP);
 	config_dir.append(NEWSBEUTER_CONFIG_SUBDIR);
 
-	if (setup_dirs_xdg(env_home))
+	if (setup_dirs_xdg(env_home, silent))
 		return;
 
 	mkdir(config_dir.c_str(),0700); // create configuration directory if it doesn't exist
@@ -183,9 +188,9 @@ controller::~controller() {
 	delete api;
 
 	scope_mutex feedslock(&feeds_mutex);
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
 		scope_mutex lock(&((*it)->item_mutex));
-		(*it)->items().clear();
+		(*it)->clear_items();
 	}
 	feeds.clear();
 }
@@ -197,8 +202,6 @@ void controller::set_view(view * vv) {
 void controller::run(int argc, char * argv[]) {
 	int c;
 
-	setup_dirs();
-
 	::signal(SIGINT, ctrl_c_action);
 	::signal(SIGPIPE, ignore_signal);
 	::signal(SIGHUP, ctrl_c_action);
@@ -214,8 +217,23 @@ void controller::run(int argc, char * argv[]) {
 	bool silent = false;
 	bool execute_cmds = false;
 
+	static char getopt_str[] = "i:erhqu:c:C:d:l:vVoxXI:E:";
+
 	do {
-		if((c = ::getopt(argc,argv,"i:erhqu:c:C:d:l:vVoxXI:E:"))<0)
+		if ((c = ::getopt(argc,argv,getopt_str)) < 0)
+				continue;
+		if (strchr("iexq", c) != NULL) {
+			silent = true;
+			break;
+		}
+	} while (c != -1);
+
+	setup_dirs(silent);
+
+	optind = 1;
+
+	do {
+		if((c = ::getopt(argc,argv,getopt_str))<0)
 			continue;
 		switch (c) {
 			case ':': /* fall-through */
@@ -226,7 +244,6 @@ void controller::run(int argc, char * argv[]) {
 				if (do_export)
 					usage(argv[0]);
 				do_import = true;
-				silent = true;
 				importfile = optarg;
 				break;
 			case 'r':
@@ -236,7 +253,6 @@ void controller::run(int argc, char * argv[]) {
 				if (do_import)
 					usage(argv[0]);
 				do_export = true;
-				silent = true;
 				break;
 			case 'h':
 				usage(argv[0]);
@@ -264,10 +280,6 @@ void controller::run(int argc, char * argv[]) {
 				break;
 			case 'x':
 				execute_cmds = true;
-				silent = true;
-				break;
-			case 'q':
-				silent = true;
 				break;
 			case 'd': // this is an undocumented debug commandline option!
 				GetLogger().set_logfile(optarg);
@@ -298,6 +310,7 @@ void controller::run(int argc, char * argv[]) {
 		}
 	} while (c != -1);
 
+
 	if (show_version) {
 		version_information(argv[0], show_version);
 	}
@@ -418,6 +431,10 @@ void controller::run(int argc, char * argv[]) {
 		api = new googlereader_api(&cfg);
 		urlcfg = new googlereader_urlreader(&cfg, url_file, api);
 		real_offline_mode = offline_mode;
+	} else if (type == "ttrss") {
+		api = new ttrss_api(&cfg);
+		urlcfg = new ttrss_urlreader(&cfg, url_file, api);
+		real_offline_mode = offline_mode;
 	} else {
 		LOG(LOG_ERROR,"unknown urls-source `%s'", urlcfg->get_source().c_str());
 	}
@@ -450,7 +467,7 @@ void controller::run(int argc, char * argv[]) {
 		}
 		if (api && type == "googlereader") { // ugly hack!
 			std::vector<google_replay_pair> actions = rsscache->get_google_replay();
-			if (actions.size() > 0) {
+			if (!actions.empty()) {
 				std::cout << _("Updating Google Reader unread states...");
 				std::cout.flush();
 
@@ -472,6 +489,8 @@ void controller::run(int argc, char * argv[]) {
 			msg = utils::strprintf(_("It looks like the OPML feed you subscribed contains no feeds. Please fill it with feeds, and try again."));
 		} else if (type == "googlereader") {
 			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your Google Reader account. Please do so, and try again."));
+		} else if (type == "ttrss") {
+			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your Tiny Tiny RSS account. Please do so, and try again."));
 		} else {
 			assert(0); // shouldn't happen
 		}
@@ -530,7 +549,7 @@ void controller::run(int argc, char * argv[]) {
 		std::cout << _("Prepopulating query feeds...");
 		std::cout.flush();
 		scope_mutex feedslock(&feeds_mutex);
-		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();it++) {
+		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
 			if ((*it)->rssurl().substr(0,6) == "query:") {
 				(*it)->update_items(get_all_feeds_unlocked());
 			}
@@ -787,7 +806,7 @@ void controller::reload_all(bool unattended) {
 
 	{
 		scope_mutex feedlock(&feeds_mutex);
-		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();it++) {
+		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
 			(*it)->reset_status();
 		}
 		size = feeds.size();
@@ -817,7 +836,7 @@ void controller::reload_all(bool unattended) {
 		LOG(LOG_DEBUG, "controller::reload_all: starting my own reload...");
 		this->reload_range(partitions[num_threads-1].first, partitions[num_threads-1].second, size, unattended);
 		LOG(LOG_DEBUG, "controller::reload_all: joining other threads...");
-		for (std::vector<pthread_t>::iterator it=threads.begin();it!=threads.end();it++) {
+		for (std::vector<pthread_t>::iterator it=threads.begin();it!=threads.end();++it) {
 			::pthread_join(*it, NULL);
 		}
 	}
@@ -832,12 +851,18 @@ void controller::reload_all(bool unattended) {
 	unsigned int unread_feeds2, unread_articles2;
 	compute_unread_numbers(unread_feeds2, unread_articles2);
 	bool notify_always = cfg.get_configvalue_as_bool("notify-always");
-	if (notify_always || unread_feeds2 != unread_feeds || unread_articles2 != unread_articles) {
+	if (notify_always || unread_feeds2 > unread_feeds || unread_articles2 > unread_articles) {
+		int article_count = unread_articles2 - unread_articles;
+		int feed_count = unread_feeds2 - unread_feeds;
+
+		LOG(LOG_DEBUG, "unread article count: %d", article_count);
+		LOG(LOG_DEBUG, "unread feed count: %d", feed_count);
+
 		fmtstr_formatter fmt;
 		fmt.register_fmt('f', utils::to_s(unread_feeds2));
 		fmt.register_fmt('n', utils::to_s(unread_articles2));
-		fmt.register_fmt('d', utils::to_s(unread_articles2 - unread_articles));
-		fmt.register_fmt('D', utils::to_s(unread_feeds2 - unread_feeds));
+		fmt.register_fmt('d', utils::to_s(article_count >= 0 ? article_count : 0));
+		fmt.register_fmt('D', utils::to_s(feed_count >= 0 ? feed_count : 0));
 		this->notify(fmt.do_format(cfg.get_configvalue("notify-format")));
 	}
 }
@@ -1125,7 +1150,7 @@ void controller::enqueue_url(const std::string& url, std::tr1::shared_ptr<rss_fe
 			getline(f, line);
 			if (!f.eof() && line.length() > 0) {
 				std::vector<std::string> fields = utils::tokenize_quoted(line);
-				if (fields.size() > 0 && fields[0] == url) {
+				if (!fields.empty() && fields[0] == url) {
 					url_found = true;
 					break;
 				}
@@ -1172,7 +1197,7 @@ void controller::reload_urls_file() {
 				rsscache->internalize_rssfeed(new_feed, ignore_disp ? &ign : NULL);
 			} catch(const dbexception& e) {
 				LOG(LOG_ERROR, "controller::reload_urls_file: caught exception: %s", e.what());
-				throw e;
+				throw;
 			}
 			new_feeds.push_back(new_feed);
 		}
@@ -1338,7 +1363,7 @@ void controller::save_feed(std::tr1::shared_ptr<rss_feed> feed, unsigned int pos
 		{
 			unsigned int order = feeds[pos]->get_order();
 			scope_mutex itemlock(&feeds[pos]->item_mutex);
-			feeds[pos]->items().clear();
+			feeds[pos]->clear_items();
 			feed->set_order(order);
 		}
 		feeds[pos] = feed;
@@ -1422,7 +1447,7 @@ void controller::export_read_information(const std::string& readinfofile) {
 	std::fstream f;
 	f.open(readinfofile.c_str(), std::fstream::out);
 	if (f.is_open()) {
-		for (std::vector<std::string>::iterator it=guids.begin();it!=guids.end();it++) {
+		for (std::vector<std::string>::iterator it=guids.begin();it!=guids.end();++it) {
 			f << *it << std::endl;
 		}
 	}
@@ -1526,7 +1551,7 @@ void controller::dump_config(const std::string& filename) {
 	std::fstream f;
 	f.open(filename.c_str(), std::fstream::out);
 	if (f.is_open()) {
-		for (std::vector<std::string>::iterator it=configlines.begin();it!=configlines.end();it++) {
+		for (std::vector<std::string>::iterator it=configlines.begin();it!=configlines.end();++it) {
 			f << *it << std::endl;
 		}
 	}
@@ -1561,4 +1586,18 @@ std::vector<std::tr1::shared_ptr<rss_feed> > controller::get_all_feeds_unlocked(
 	return feeds;
 }
 
+
+unsigned int controller::get_feed_count_per_tag(const std::string& tag) {
+	unsigned int count = 0;
+	scope_mutex feedslock(&feeds_mutex);
+
+	for (std::vector<std::tr1::shared_ptr<rss_feed> >::const_iterator it=feeds.begin();it!=feeds.end();it++) {
+		if ((*it)->matches_tag(tag)) {
+			count++;
+		}
+	}
+
+	return count;
+}
+
 }
