@@ -150,12 +150,15 @@ void feedlist_formaction::process_operation(operation op, bool automatic, std::v
 				}
 			}
 			break;
-		case OP_OPENINBROWSER: {
+		case OP_OPENINBROWSER: 
+			if (feeds_shown > 0 && feedpos.length() > 0) {
 				std::tr1::shared_ptr<rss_feed> feed = v->get_ctrl()->get_feed(pos);
 				if (feed) {
 					LOG(LOG_INFO, "feedlist_formaction: opening feed at position `%s': %s", feedpos.c_str(), feed->link().c_str());
 					v->open_in_browser(feed->link());
 				}
+			} else {
+				v->show_error(_("No feed selected!"));
 			}
 			break;
 		case OP_RELOADALL:
@@ -594,7 +597,7 @@ void feedlist_formaction::handle_cmdline(const std::string& cmd) {
 	} else {
 		// hand over all other commands to formaction
 		std::vector<std::string> tokens = utils::tokenize_quoted(cmd, " \t");
-		if (tokens.size() > 0) {
+		if (!tokens.empty()) {
 			if (tokens[0] == "tag") {
 				if (tokens.size() >= 2 && tokens[1] != "") {
 					tag = tokens[1];
@@ -703,9 +706,12 @@ void feedlist_formaction::op_start_search() {
 			v->show_error(utils::strprintf(_("Error while searching for `%s': %s"), searchphrase.c_str(), e.what()));
 			return;
 		}
-		if (items.size() > 0) {
+		if (!items.empty()) {
 			search_dummy_feed->item_mutex.lock();
-			search_dummy_feed->items() = items;
+			search_dummy_feed->clear_items();
+			for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items.begin();it!=items.end();++it) {
+				search_dummy_feed->add_item(*it);
+			}
 			search_dummy_feed->item_mutex.unlock();
 			v->push_searchresult(search_dummy_feed, searchphrase);
 		} else {
