@@ -75,7 +75,8 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 	bool itunes_hack = false;
 	size_t inside_script = 0;
 	size_t inside_style = 0;
-	unsigned int ol_count = 1;
+	std::vector<unsigned int> ol_counts;
+	std::vector<char> ol_types;
 	htmltag current_tag;
 	int link_num = -1;
 	std::vector<Table> tables;
@@ -200,7 +201,28 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 					case TAG_OL:
 						inside_list = true;
 						is_ol = true;
-						ol_count = 1;
+						{
+							unsigned int ol_count = 1;
+							try {
+								std::string ol_count_str = xpp.getAttributeValue("start");
+								std::istringstream is(ol_count_str);
+								is >> ol_count;
+							} catch (const std::invalid_argument& ) {
+								ol_count = 1;
+							}
+							ol_counts.push_back(ol_count);
+
+							std::string ol_type;
+							try {
+								ol_type = xpp.getAttributeValue("type");
+								if (ol_type != "1" && ol_type != "a" && ol_type != "A" && ol_type != "i" && ol_type != "I") {
+									ol_type = "1";
+								}
+							} catch (const std::invalid_argument& ) {
+								ol_type = "1";
+							}
+							ol_types.push_back(ol_type[0]);
+						}
 						add_nonempty_line(curline, tables, lines);
 						add_line("", tables, lines);
 						prepare_newline(curline,  tables.size() ? 0 : indent_level);	
@@ -226,8 +248,8 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						prepare_newline(curline,  tables.size() ? 0 : indent_level);
 						indent_level+=2;
 						if (is_ol) {
-							curline.append(utils::strprintf("%2u.", ol_count));
-							++ol_count;
+							curline.append(utils::strprintf("%s.", format_ol_count(ol_counts[ol_counts.size()-1], ol_types[ol_types.size()-1]).c_str()));
+							++ol_counts[ol_counts.size()-1];
 						} else {
 							curline.append("  * ");
 						}
@@ -291,7 +313,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 					}
 
 					case TAG_TR:
-						if (tables.size())
+						if (!tables.empty())
 							tables.back().start_row();
 						break;
 
@@ -303,7 +325,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						} catch (const std::invalid_argument& ) {
 							// is ok, span 1 than
 						}
-						if (tables.size())
+						if (!tables.empty())
 							tables.back().start_cell(span);
 						break;
 					}
@@ -328,6 +350,9 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						break;
 
 					case TAG_OL:
+						ol_types.pop_back();
+						ol_counts.pop_back();
+						// fall-through
 					case TAG_UL:
 						inside_list = false;
 						if (inside_li) {
@@ -442,14 +467,14 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						add_nonempty_line(curline, tables, lines);
 						prepare_newline(curline, 0); // no indent in tables
 
-						if (tables.size()) {
+						if (!tables.empty()) {
 							std::vector<std::string> table_text;
 							tables.back().complete_cell();
 							tables.back().complete_row();
 							render_table(tables.back(), table_text);
 							tables.pop_back();
 
-							if (tables.size()) { // still a table on the outside?
+							if (!tables.empty()) { // still a table on the outside?
 								for(size_t idx=0; idx < table_text.size(); ++idx)
 								tables.back().add_text(table_text[idx]); // add rendered table to current cell
 							} else {
@@ -469,7 +494,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						add_nonempty_line(curline, tables, lines);
 						prepare_newline(curline, 0); // no indent in tables
 
-						if (tables.size())
+						if (!tables.empty())
 							tables.back().complete_row();
 						break;
 
@@ -478,7 +503,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						add_nonempty_line(curline, tables, lines);
 						prepare_newline(curline, 0); // no indent in tables
 
-						if (tables.size())
+						if (!tables.empty())
 							tables.back().complete_cell();
 						break;
 
@@ -536,7 +561,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						unsigned int i=0;
 						bool new_line = false;
 
-						if (!line_is_nonempty(curline) && words.size() > 0 && words[0] == " ") {
+						if (!line_is_nonempty(curline) && !words.empty() && words[0] == " ") {
 							words.erase(words.begin());
 						}
 
@@ -567,7 +592,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 	add_nonempty_line(curline, tables, lines);
 	
 	// force all tables to be closed and rendered
-	while(tables.size()) {
+	while(!tables.empty()) {
 		std::vector<std::string> table_text;
 		render_table(tables.back(), table_text);
 		tables.pop_back();
@@ -658,7 +683,9 @@ void htmlrenderer::Table::start_cell(size_t span)
 
 void htmlrenderer::Table::complete_cell()
 {
-	rows.back().complete_cell();
+    if (rows.size()) {
+	    rows.back().complete_cell();
+    }
 }
 
 void htmlrenderer::Table::start_row()
@@ -769,5 +796,52 @@ void htmlrenderer::render_table(const Table& table, std::vector<std::string>& li
 	}
 }
 
+std::string htmlrenderer::get_char_numbering(unsigned int count) {
+	std::string result;
+	do {
+		count--;
+		result.append(1, 'a'+(count % 26));
+		count /= 26;
+	} while (count > 0);
+	std::reverse(result.begin(), result.end());
+	return result;
+}
+
+std::string htmlrenderer::get_roman_numbering(unsigned int count) {
+	unsigned int values[] = { 1000, 900, 500, 400, 100, 90, 50, 40, 10, 9, 5, 4, 1 };
+	const char * numerals[] = { "m", "cm", "d", "cd", "c", "xc", "l", "xl", "x", "ix", "v", "iv", "i" };
+	std::string result;
+	for (unsigned int i=0;i<(sizeof(values)/sizeof(values[0]));i++) {
+		while (count >= values[i]) {
+			count -= values[i];
+			result.append(numerals[i]);
+		}
+	}
+	return result;
+}
+
+
+std::string htmlrenderer::format_ol_count(unsigned int count, char type) {
+	switch (type) {
+		case 'a':
+			return get_char_numbering(count);
+		case 'A': {
+			std::string num = get_char_numbering(count);
+			std::transform(num.begin(), num.end(), num.begin(), ::toupper);
+			return num;
+		}
+		case 'i':
+			return get_roman_numbering(count);
+		case 'I': {
+			std::string roman = get_roman_numbering(count);
+			std::transform(roman.begin(), roman.end(), roman.begin(), ::toupper);
+			return roman;
+		}
+		case '1':
+		default:
+			return utils::strprintf("%2u", count);
+	}
+}
+
 }
 
