@@ -139,15 +139,22 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 		case OP_SHOWURLS:
 			if (itemposname.length() > 0 && visible_items.size() != 0) {
 				if (itempos < visible_items.size()) {
-					std::vector<linkpair> links;
-					std::vector<std::string> lines;
-					htmlrenderer rnd(80);
-					std::string baseurl = visible_items[itempos].first->get_base() != "" ? visible_items[itempos].first->get_base() : visible_items[itempos].first->link();
-					rnd.render(visible_items[itempos].first->description(), lines, links, baseurl);
-					if (links.size() > 0) {
-						v->push_urlview(links);
+					std::string urlviewer = v->get_cfg()->get_configvalue("external-url-viewer");
+					if (urlviewer == "") {
+						std::vector<linkpair> links;
+						std::vector<std::string> lines;
+						htmlrenderer rnd(80);
+						std::string baseurl = visible_items[itempos].first->get_base() != "" ? visible_items[itempos].first->get_base() : visible_items[itempos].first->feedurl();
+						rnd.render(visible_items[itempos].first->description(), lines, links, baseurl);
+						if (!links.empty()) {
+							v->push_urlview(links);
+						} else {
+							v->show_error(_("URL list empty."));
+						}
 					} else {
-						v->show_error(_("URL list empty."));
+						qna_responses.clear();
+						qna_responses.push_back(urlviewer);
+						this->finished_qna(OP_PIPE_TO);
 					}
 				}
 			} else {
@@ -565,14 +572,16 @@ void itemlist_formaction::qna_start_search() {
 		return;
 	}
 
-	if (items.size() == 0) {
+	if (items.empty()) {
 		v->show_error(_("No results."));
 		return;
 	}
 
 	{
-	    scope_mutex lock(&search_dummy_feed->item_mutex);
-	    search_dummy_feed->items() = items;
+		scope_mutex lock(&search_dummy_feed->item_mutex);
+		for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items.begin();it!=items.end();++it) {
+			search_dummy_feed->add_item(*it);
+		}
 	}
 
 	if (show_searchresult) {
@@ -590,7 +599,7 @@ void itemlist_formaction::do_update_visible_items() {
 	scope_mutex lock(&feed->item_mutex);
 	std::vector<std::tr1::shared_ptr<rss_item> >& items = feed->items();
 
-	visible_items.clear();
+	std::vector<itemptr_pos_pair> new_visible_items;
 
 	/*
 	 * this method doesn't redraw, all it does is to go through all
@@ -602,12 +611,14 @@ void itemlist_formaction::do_update_visible_items() {
 	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it = items.begin(); it != items.end(); ++it, ++i) {
 		(*it)->set_index(i+1);
 		if (!apply_filter || m.matches(it->get())) {
-			visible_items.push_back(itemptr_pos_pair(*it, i));
+			new_visible_items.push_back(itemptr_pos_pair(*it, i));
 		}
 	}
 
 	LOG(LOG_DEBUG, "itemlist_formaction::do_update_visible_items: size = %u", visible_items.size());
 
+	visible_items = new_visible_items;
+
 	do_redraw = true;
 }
 
@@ -622,7 +633,12 @@ void itemlist_formaction::prepare() {
 		do_redraw = true;
 	}
 
-	do_update_visible_items();
+	try {
+		do_update_visible_items();
+	} catch (matcherexception& e) {
+		v->show_error(utils::strprintf(_("Error: applying the filter failed: %s"), e.what()));
+		return;
+	}
 
 	if (v->get_cfg()->get_configvalue_as_bool("mark-as-read-on-hover")) {
 		std::string itemposname = f->get("itempos");
@@ -870,7 +886,7 @@ void itemlist_formaction::handle_cmdline(const std::string& cmd) {
 		handle_cmdline_num(idx);
 	} else {
 		std::vector<std::string> tokens = utils::tokenize_quoted(cmd);
-		if (tokens.size() == 0)
+		if (tokens.empty())
 			return;
 		if (tokens[0] == "save" && tokens.size() >= 2) {
 			std::string filename = utils::resolve_tilde(tokens[1]);
