@@ -260,12 +260,20 @@ void itemview_formaction::process_operation(operation op, bool automatic, std::v
 				this->start_qna(qna, OP_INT_EDITFLAGS_END);
 			}
 			break;
-		case OP_SHOWURLS:
-			LOG(LOG_DEBUG, "view::run_itemview: showing URLs");
-			if (links.size() > 0) {
-				v->push_urlview(links);
-			} else {
-				v->show_error(_("URL list empty."));
+		case OP_SHOWURLS: {
+				std::string urlviewer = v->get_cfg()->get_configvalue("external-url-viewer");
+				LOG(LOG_DEBUG, "view::run_itemview: showing URLs");
+				if (urlviewer == "") {
+					if (links.size() > 0) {
+						v->push_urlview(links);
+					} else {
+						v->show_error(_("URL list empty."));
+					}
+				} else {
+					qna_responses.clear();
+					qna_responses.push_back(urlviewer);
+					this->finished_qna(OP_PIPE_TO);
+				}
 			}
 			break;
 		case OP_DELETE:
@@ -450,7 +458,7 @@ void itemview_formaction::render_source(std::vector<std::string>& lines, std::st
 
 void itemview_formaction::handle_cmdline(const std::string& cmd) {
 	std::vector<std::string> tokens = utils::tokenize_quoted(cmd);
-	if (tokens.size() > 0) {
+	if (!tokens.empty()) {
 		if (tokens[0] == "save" && tokens.size() >= 2) {
 			std::string filename = utils::resolve_tilde(tokens[1]);
 			std::tr1::shared_ptr<rss_item> item = feed->get_item_by_guid(guid);
@@ -517,12 +525,12 @@ void itemview_formaction::finished_qna(operation op) {
 	}
 }
 
-std::vector<std::string> itemview_formaction::render_html(const std::string& source, std::vector<linkpair>& thelinks, const std::string& feedurl, unsigned int render_width) {
+std::vector<std::string> itemview_formaction::render_html(const std::string& source, std::vector<linkpair>& thelinks, const std::string& url, unsigned int render_width) {
 	std::vector<std::string> lines;
 	std::string renderer = v->get_cfg()->get_configvalue("html-renderer");
 	if (renderer == "internal") {
 		htmlrenderer rnd(render_width);
-		rnd.render(source, lines, thelinks, feedurl);
+		rnd.render(source, lines, thelinks, url);
 	} else {
 		char * argv[4];
 		argv[0] = const_cast<char *>("/bin/sh");
