@@ -36,6 +36,7 @@ rss_feed::rss_feed(cache * c) : ch(c), empty(true), is_rtl_(false), idx(0), stat
 
 rss_feed::~rss_feed() {
 	// LOG(LOG_CRITICAL, "delete rss_feed");
+	clear_items();
 }
 
 // rss_item setters
@@ -105,7 +106,7 @@ void rss_item::set_unread(bool u) {
 		} catch (const dbexception& e) {
 			// if the update failed, restore the old unread flag and rethrow the exception
 			unread_ = old_u; 
-			throw e;
+			throw;
 		}
 	}
 }
@@ -185,7 +186,7 @@ std::string rss_item::description() const {
 std::string rss_feed::title() const {
 	bool found_title = false;
 	std::string alt_title;
-	for (std::vector<std::string>::const_iterator it=tags_.begin();it!=tags_.end();it++) {
+	for (std::vector<std::string>::const_iterator it=tags_.begin();it!=tags_.end();++it) {
 		if (it->substr(0,1) == "~") {
 			found_title = true;
 			alt_title = it->substr(1, it->length()-1);
@@ -205,10 +206,9 @@ std::tr1::shared_ptr<rss_item> rss_feed::get_item_by_guid(const std::string& gui
 }
 
 std::tr1::shared_ptr<rss_item> rss_feed::get_item_by_guid_unlocked(const std::string& guid) {
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items_.begin();it!=items_.end();++it) {
-		if ((*it)->guid() == guid) {
-			return *it;
-		}
+	std::tr1::unordered_map<std::string, std::tr1::shared_ptr<rss_item> >::const_iterator it;
+	if ((it = items_guid_map.find(guid)) != items_guid_map.end()) {
+		return it->second;
 	}
 	LOG(LOG_DEBUG, "rss_feed::get_item_by_guid_unlocked: hit dummy item!");
 	// abort();
@@ -363,7 +363,7 @@ void rss_ignores::handle_action(const std::string& action, const std::vector<std
 }
 
 void rss_ignores::dump_config(std::vector<std::string>& config_output) {
-	for (std::vector<feedurl_expr_pair>::iterator it = ignores.begin();it!=ignores.end();it++) {
+	for (std::vector<feedurl_expr_pair>::iterator it = ignores.begin();it!=ignores.end();++it) {
 		std::string configline = "ignore-article ";
 		if (it->first == "*")
 			configline.append("*");
@@ -373,10 +373,10 @@ void rss_ignores::dump_config(std::vector<std::string>& config_output) {
 		configline.append(utils::quote(it->second->get_expression()));
 		config_output.push_back(configline);
 	}
-	for (std::vector<std::string>::iterator it=ignores_lastmodified.begin();it!=ignores_lastmodified.end();it++) {
+	for (std::vector<std::string>::iterator it=ignores_lastmodified.begin();it!=ignores_lastmodified.end();++it) {
 		config_output.push_back(utils::strprintf("always-download %s", utils::quote(*it).c_str()));
 	}
-	for (std::vector<std::string>::iterator it=resetflag.begin();it!=resetflag.end();it++) {
+	for (std::vector<std::string>::iterator it=resetflag.begin();it!=resetflag.end();++it) {
 		config_output.push_back(utils::strprintf("reset-unread-on-update %s", utils::quote(*it).c_str()));
 	}
 }
@@ -430,6 +430,7 @@ void rss_feed::update_items(std::vector<std::tr1::shared_ptr<rss_feed> > feeds)
 	matcher m(query);
 
 	items_.clear();
+	items_guid_map.clear();
 
 	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
 		if ((*it)->rssurl().substr(0,6) != "query:") { // don't fetch items from other query feeds!
@@ -438,6 +439,7 @@ void rss_feed::update_items(std::vector<std::tr1::shared_ptr<rss_feed> > feeds)
 					LOG(LOG_DEBUG, "rss_feed::update_items: matcher matches!");
 					(*jt)->set_feedptr(*it);
 					items_.push_back(*jt);
+					items_guid_map[(*jt)->guid()] = *jt;
 				}
 			}
 		}
@@ -524,7 +526,7 @@ void rss_feed::sort_unlocked(const std::string& method) {
 	std::vector<std::string> methods = utils::tokenize(method,"-");
 	bool reverse = false;
 
-	if (methods.size() > 0 && methods[0] == "date") { // date is descending by default
+	if (!methods.empty() && methods[0] == "date") { // date is descending by default
 		if (methods.size() > 1 && methods[1] == "asc") {
 			reverse = true;
 		}
@@ -534,7 +536,7 @@ void rss_feed::sort_unlocked(const std::string& method) {
 		}
 	}
 
-	if (methods.size() > 0) {
+	if (!methods.empty()) {
 		if (methods[0] == "title") {
 			std::stable_sort(items_.begin(), items_.end(), sort_item_by_title(reverse));
 		} else if (methods[0] == "flags") {
@@ -566,6 +568,7 @@ void rss_feed::purge_deleted_items() {
 	std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items_.begin();
 	while (it!=items_.end()) {
 		if ((*it)->deleted()) {
+			items_guid_map.erase((*it)->guid());
 			items_.erase(it);
 			it = items_.begin(); // items_ modified -> iterator invalidated
 		} else {
@@ -576,7 +579,7 @@ void rss_feed::purge_deleted_items() {
 
 void rss_feed::set_feedptrs(std::tr1::shared_ptr<rss_feed> self) {
 	scope_mutex lock(&item_mutex);
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items_.begin();it!=items_.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items_.begin();it!=items_.end();++it) {
 		(*it)->set_feedptr(self);
 	}
 }
@@ -597,7 +600,7 @@ std::string rss_feed::get_status() {
 
 void rss_feed::unload() {
 	scope_mutex lock(&item_mutex);
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items_.begin();it!=items_.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items_.begin();it!=items_.end();++it) {
 		(*it)->unload();
 	}
 }
