@@ -24,6 +24,18 @@
 #include <stfl.h>
 #include <libxml/uri.h>
 
+#if HAVE_GCRYPT
+#include <gnutls/gnutls.h>
+#include <gcrypt.h>
+#include <errno.h>
+#include <pthread.h>
+GCRY_THREAD_OPTION_PTHREAD_IMPL;
+#endif
+
+#if HAVE_OPENSSL
+#include <openssl/crypto.h>
+#endif
+
 namespace newsbeuter {
 
 std::vector<std::string> utils::tokenize_quoted(const std::string& str, std::string delimiters) {
@@ -309,8 +321,8 @@ std::string utils::get_command_output(const std::string& cmd) {
 	FILE * f = popen(cmd.c_str(), "r");
 	std::string buf;
 	char cbuf[1024];
-	size_t s;
 	if (f) {
+		size_t s;
 		while ((s = fread(cbuf, 1, sizeof(cbuf), f)) > 0) {
 			buf.append(cbuf, s);
 		}
@@ -344,7 +356,7 @@ std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcon
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEDATA, &buf);
 
 	if (authinfo) {
-		curl_easy_setopt(easyhandle, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
+		curl_easy_setopt(easyhandle, CURLOPT_HTTPAUTH, get_auth_method(cfgcont->get_configvalue("http-auth-method")));
 		curl_easy_setopt(easyhandle, CURLOPT_USERPWD, authinfo);
 	}
 
@@ -383,8 +395,6 @@ std::string utils::run_program(char * argv[], const std::string& input) {
 	int ipipe[2]; int opipe[2];
 	pipe(ipipe);  pipe(opipe);
 
-	int errfd = ::open("/dev/null", O_WRONLY);
-
 	int rc = fork();
 	switch (rc) {
 		case -1: break;
@@ -392,6 +402,8 @@ std::string utils::run_program(char * argv[], const std::string& input) {
 				close(ipipe[1]);   close(opipe[0]);
 				dup2(ipipe[0], 0); dup2(opipe[1], 1);
 				close(2);
+
+				int errfd = ::open("/dev/null", O_WRONLY);
 				if (errfd != -1) dup2(errfd, 2);
 
 				execvp(argv[0], argv);
@@ -648,7 +660,7 @@ size_t utils::wcswidth_stfl(const std::wstring& str, size_t size) {
 std::string utils::join(const std::vector<std::string>& strings, const std::string& separator) {
 	std::string result;
 
-	for (std::vector<std::string>::const_iterator it=strings.begin();it!=strings.end();it++) {
+	for (std::vector<std::string>::const_iterator it=strings.begin();it!=strings.end();++it) {
 		result.append(*it);
 		result.append(separator);
 	}
@@ -725,8 +737,8 @@ std::string utils::quote(const std::string& str) {
 
 unsigned int utils::get_random_value(unsigned int max) {
 	static bool initialized = false;
-	unsigned int var;
 	if (!initialized) {
+		unsigned int var;
 		initialized = true;
 		srand(~(time(NULL) ^ getpid() ^ getppid() ^ var));
 	}
@@ -774,7 +786,7 @@ void utils::set_common_curl_options(CURL * handle, configcontainer * cfg) {
 	if (proxy != "")
 		curl_easy_setopt(handle, CURLOPT_PROXY, proxy.c_str());
 	if (proxyauth != "") {
-		curl_easy_setopt(handle, CURLOPT_PROXYAUTH, get_proxy_auth_method(proxyauthmethod));
+		curl_easy_setopt(handle, CURLOPT_PROXYAUTH, get_auth_method(proxyauthmethod));
 		curl_easy_setopt(handle, CURLOPT_PROXYUSERPWD, proxyauth.c_str());
 	}
 	if (proxytype != "") {
@@ -822,7 +834,7 @@ std::string utils::get_prop(xmlNode * node, const char * prop, const char * ns)
 	return retval;
 }
 
-int utils::get_proxy_auth_method(const std::string& type) {
+int utils::get_auth_method(const std::string& type) {
 	if (type == "any")
 		return CURLAUTH_ANY;
 	if (type == "basic")
@@ -881,4 +893,45 @@ std::wstring utils::clean_nonprintable_characters(std::wstring text) {
 	return text;
 }
 
+/*
+ * See http://curl.haxx.se/libcurl/c/libcurl-tutorial.html#Multi-threading for a reason why we do this.
+ */
+
+#if HAVE_OPENSSL
+static mutex * openssl_mutexes = NULL;
+static int openssl_mutexes_size = 0;
+
+static void openssl_mth_locking_function(int mode, int n, const char * file, int line) {
+	if (n < 0 || n >= openssl_mutexes_size) {
+		LOG(LOG_ERROR,"openssl_mth_locking_function: index is out of bounds (called by %s:%d)", file, line);
+		return;
+	}
+	if (mode & CRYPTO_LOCK) {
+		LOG(LOG_DEBUG, "OpenSSL lock %d: %s:%d", n, file, line);
+		openssl_mutexes[n].lock();
+	} else {
+		LOG(LOG_DEBUG, "OpenSSL unlock %d: %s:%d", n, file, line);
+		openssl_mutexes[n].unlock();
+	}
+}
+
+static unsigned long openssl_mth_id_function(void) {
+	return (unsigned long)pthread_self();
+}
+#endif
+
+void utils::initialize_ssl_implementation(void) {
+#if HAVE_OPENSSL
+	openssl_mutexes_size = CRYPTO_num_locks();
+	openssl_mutexes = new mutex[openssl_mutexes_size];
+	CRYPTO_set_id_callback(openssl_mth_id_function);
+	CRYPTO_set_locking_callback(openssl_mth_locking_function);
+#endif
+
+#if HAVE_GCRYPT
+	gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+	gnutls_global_init();
+#endif
+}
+
 }
