@@ -40,7 +40,7 @@
 #include <config.h>
 #include <sys/param.h>
 #include <string.h>
-#include <ncursesw/ncurses.h>
+#include <ncurses.h>
 
 
 extern "C" {
@@ -74,7 +74,7 @@ void view::set_keymap(keymap * k) {
 
 
 void view::update_bindings() {
-	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it) {
 		if (*it) {
 			set_bindings(*it);
 		}
@@ -165,7 +165,7 @@ void view::run() {
 		// we signal "oh, you will receive an operation soon"
 		fa->prepare();
 
-		if (macrocmds.size() > 0) {
+		if (!macrocmds.empty()) {
 			// if there is any macro command left to process, we do so
 
 			fa->get_form()->run(-1);
@@ -417,6 +417,8 @@ void view::push_searchresult(std::tr1::shared_ptr<rss_feed> feed, const std::str
 void view::push_itemlist(std::tr1::shared_ptr<rss_feed> feed) {
 	assert(feed != NULL);
 
+	feed->purge_deleted_items();
+
 	if (feed->rssurl().substr(0,6) == "query:") {
 		set_status(_("Updating query feed..."));
 		feed->update_items(ctrl->get_all_feeds());
@@ -571,7 +573,7 @@ char view::confirm(const std::string& prompt, const std::string& charset) {
 }
 
 void view::notify_itemlist_change(std::tr1::shared_ptr<rss_feed> feed) {
-	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it) {
 		if (*it != NULL && (*it)->id() == "articlelist") {
 			std::tr1::shared_ptr<itemlist_formaction> itemlist = std::tr1::dynamic_pointer_cast<itemlist_formaction, formaction>(*it);
 			if (itemlist != NULL) {
@@ -790,20 +792,20 @@ void view::pop_current_formaction() {
 	std::tr1::shared_ptr<formaction> f = get_current_formaction();
 	std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();
 	for (unsigned int i=0;i<current_formaction;i++)
-		it++;
+		++it;
 	formaction_stack.erase(it);
 	if (f == NULL) {
 		current_formaction = formaction_stack_size() - 1; // XXX TODO this is not correct... we'd need to return to the previous one, but NULL formactions have no parent
 	} else if (formaction_stack.size() > 0) {
 		// first, we set back the parent formactions of those who reference the formaction we just removed
-		for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++) {
+		for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it) {
 			if ((*it)->get_parent_formaction() == f) {
 				(*it)->set_parent_formaction(formaction_stack[0]);
 			}
 		}
 		// we set the new formaction based on the removed formaction's parent.
 		unsigned int i=0;
-		for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++,i++) {
+		for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it,i++) {
 			if (*it == f->get_parent_formaction()) {
 				current_formaction = i;
 				break;
@@ -827,12 +829,12 @@ void view::remove_formaction(unsigned int pos) {
 	std::tr1::shared_ptr<formaction> f = formaction_stack[pos];
 	std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();
 	for (unsigned int i=0;i<pos;i++)
-		it++;
+		++it;
 	formaction_stack.erase(it);
 	current_formaction--;
 	if (f != NULL && formaction_stack.size() > 0) {
 		// we set back the parent formactions of those who reference the formaction we just removed
-		for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++) {
+		for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it) {
 			if ((*it)->get_parent_formaction() == f) {
 				(*it)->set_parent_formaction(formaction_stack[0]);
 			}
@@ -847,7 +849,7 @@ void view::set_colors(std::map<std::string,std::string>& fgc, std::map<std::stri
 }
 
 void view::apply_colors_to_all_formactions() {
-	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++) {
+	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it) {
 		apply_colors(*it);
 	}
 	if (formaction_stack.size() > 0 && formaction_stack[current_formaction]) {
@@ -933,7 +935,7 @@ void view::set_regexmanager(regexmanager * r) {
 std::vector<std::pair<unsigned int, std::string> > view::get_formaction_names() {
 	std::vector<std::pair<unsigned int, std::string> > formaction_names;
 	unsigned int i=0;
-	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();it++,i++) {
+	for (std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();it!=formaction_stack.end();++it,i++) {
 		if (*it && (*it)->id() != "dialogs") {
 			formaction_names.push_back(std::pair<unsigned int, std::string>(i, (*it)->title()));
 		}
