@@ -31,7 +31,7 @@ using namespace newsbeuter;
 
 namespace test {
 
-lemon::test<> lemon(323);
+lemon::test<> lemon(0);
 
 void TestNewsbeuterReload() {
 	configcontainer * cfg = new configcontainer();
@@ -875,6 +875,35 @@ void TestUtilsFunction_trim() {
 	lemon.is(str, "quux", "trim end of string that ends with newline");
 }
 
+void TestOlFormatting() {
+	htmlrenderer r;
+	lemon.is(r.format_ol_count(1, '1'), " 1", "1 in digit formats to \"1\"");
+	lemon.is(r.format_ol_count(3, '1'), " 3", "3 in digit formats to \"3\"");
+	lemon.is(r.format_ol_count(3, 'a'), "c", "3 in alphabetic formats to \"c\"");
+	lemon.is(r.format_ol_count(26 + 3, 'a'), "ac", "26+3 in alphabetic formats to \"ac\"");
+	lemon.is(r.format_ol_count(3*26*26 + 5*26 + 2, 'a'), "ceb", "3*26*26 + 5*26 + 2 in alphabetic formats to \"ceb\"");
+
+	lemon.is(r.format_ol_count(3, 'A'), "C", "3 in alphabetic uppercase formats to \"C\"");
+	lemon.is(r.format_ol_count(26 + 5, 'A'), "AE", "26+5 in alphabetic uppercase formats to \"AE\"");
+	lemon.is(r.format_ol_count(27, 'A'), "AA", "27 in alphabetic uppercase formats to \"AA\"");
+	lemon.is(r.format_ol_count(26, 'A'), "Z", "26 in alphabetic uppercase formats to \"Z\"");
+	lemon.is(r.format_ol_count(26*26+26, 'A'), "ZZ", "26*26+26 in alphabetic uppercase formats to \"ZZ\"");
+	lemon.is(r.format_ol_count(25*26*26 + 26*26+26, 'A'), "YZZ", "26*26*26+26*26+26 in alphabetic uppercase formats to \"YZZ\"");
+
+	lemon.is(r.format_ol_count(1, 'i'), "i", "1 in roman numerals is i");
+	lemon.is(r.format_ol_count(2, 'i'), "ii", "2 in roman numerals is ii");
+	lemon.is(r.format_ol_count(5, 'i'), "v", "5 in roman numerals is v");
+	lemon.is(r.format_ol_count(4, 'i'), "iv", "4 in roman numerals is iv");
+	lemon.is(r.format_ol_count(6, 'i'), "vi", "6 in roman numerals is vi");
+	lemon.is(r.format_ol_count(7, 'i'), "vii", "6 in roman numerals is vii");
+	lemon.is(r.format_ol_count(10, 'i'), "x", "10 in roman numerals is x");
+
+	lemon.is(r.format_ol_count(32, 'i'), "xxxii", "32 in roman numerals is xxxii");
+	lemon.is(r.format_ol_count(1972, 'i'), "mcmlxxii", "1972 in roman numerals is mcmlxxii");
+
+	lemon.is(r.format_ol_count(2011, 'I'), "MMXI", "201 in roman numerals uppercase is MMXI");
+}
+
 } // namespace test
 
 int main(void) {
@@ -904,6 +933,7 @@ int main(void) {
 	test::TestUtilsFunctions_strwidth();
 	test::TestUtilsFunction_join();
 	test::TestUtilsFunction_trim();
+	test::TestOlFormatting();
 
 	return test::lemon.done() ? 0 : 1;
 }
